.. _VOTable standard: http://www.ivoa.net/documents/VOTable/
.. _SIA standard: http://www.ivoa.net/documents/SIA/
.. _SCS standard: http://www.ivoa.net/documents/latest/ConeSearch.html
.. _SSA standard: http://www.ivoa.net/documents/SSA/
.. _SLA standard: http://www.ivoa.net/documents/SLAP/
.. _PEP 249: http://www.python.org/dev/peps/pep-0249/
